@@ -127,6 +127,10 @@ Other flags:"
 "
   --sbcl PATH-TO-SBCL       Use PATH-TO-SBCL instead of the sbcl program
                               found in your PATH environment variable"
+#+ccl
+"
+  --ccl PATH-TO-CCL         Use PATH-TO-CCL instead of the ccl program
+                              found in your PATH environment variable"
 "
 For the latest documentation, see http://www.xach.com/lisp/buildapp/
 "))
@@ -159,7 +163,8 @@ For the latest documentation, see http://www.xach.com/lisp/buildapp/
     (format *system-load-output* "~&Fatal ~A:~%  ~A~%"
             (type-of condition) condition)
     (print (macroexpand-1 '(backtrace-as-list)) *logfile-output*)
-    (macroexpand-1 '(quit 111))))
+    #+sbcl (sb-ext:exit :code 111)
+    #+ccl (ccl:quit 111)))
 
 (defun command-line-debugger (condition previous-hook)
   "The function to call if there are errors in the command-line
@@ -264,7 +269,8 @@ it. If an exact filename is not found, file.lisp is also tried."
 (defun dumper-action-form (dumper)
   (let ((forms (mapcar 'invoke-debugger-hook-wrapper
                        (dumper-action-forms dumper))))
-    `(progn ,@forms)))
+    `(let ((*package* (find-package "CL-USER")))
+       ,@forms)))
 
 (defun dumpfile-forms (dumper)
   "Return a list of forms to be saved to a dumpfile."
